{% extends 'is_core/base.html' %}
{% load i18n %}

{% block content %}
  <h2 class="background-serialization">{% trans 'The data will be exported on background' %}</h2>
  <p>{% trans 'You will be notified after export completion' %}</p>
{% endblock %}
